
# `walt-log-tee` logging tool

`walt-log-tee` is a logging tool provided on all nodes. It allows to emit loglines. For more info about WalT logging in general, see [`walt help show logging`](logging.md). `walt-log-tee` acts the same as `walt-log-cat` except that it will not only emit loglines, but also paste them on its standard output. This can ease debugging.
For more information, see [`walt help show log-cat`](log-cat.md).

